"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
const build_kit_1 = require("@genesislcap/build-kit");
const cac_1 = tslib_1.__importDefault(require("cac"));
const consola_1 = require("consola");
const commands_1 = require("./commands");
const packageJSON = require('../package.json');
process.on('unhandledRejection', (err) => {
    consola_1.consola.error('[unhandledRejection]', err);
    process.exit(1);
});
process.on('uncaughtException', (err) => {
    consola_1.consola.error('[uncaughtException]', err);
    process.exit(1);
});
const cli = (0, cac_1.default)();
// default command
cli.command('').action(() => cli.outputHelp());
cli
    .command('analyze [folder]', 'Analyze production bundle')
    .option('-b, --builder <builder>', 'Override default builder')
    .option('-n, --no-open', "Don't launch browser window")
    .option('-e, --env <ENV_VAR1=VAL1,ENV_VAR2=VAL2,ENV3>', 'Set environment variables')
    .action((folder, options) => tslib_1.__awaiter(void 0, void 0, void 0, function* () {
    const action = yield commands_1.commands.runBuilder();
    action(folder, options, build_kit_1.ENV.PROD, build_kit_1.COMMAND.ANALYZE);
}));
cli
    .command('clean [...paths]', 'Delete specified paths (defaults to dist folder)')
    .action((paths) => tslib_1.__awaiter(void 0, void 0, void 0, function* () {
    const action = yield commands_1.commands.clean();
    action(paths);
}));
cli
    .command('build [folder]', 'Build production bundle')
    .option('-b, --builder <builder>', 'Override default builder')
    .option('-e, --env <ENV_VAR1=VAL1,ENV_VAR2=VAL2,ENV3>', 'Set environment variables')
    .action((folder, options) => tslib_1.__awaiter(void 0, void 0, void 0, function* () {
    const action = yield commands_1.commands.runBuilder();
    action(folder, options, build_kit_1.ENV.PROD, build_kit_1.COMMAND.BUILD);
}));
cli
    .command('dev [folder]', 'Start development server')
    .option('-b, --builder <builder>', 'Override default builder')
    .option('--https', 'Use HTTPS')
    .option('-n, --no-open', "Don't launch browser window")
    .option('-e, --env <ENV_VAR1=VAL1,ENV_VAR2=VAL2,ENV3>', 'Set environment variables')
    .action((folder, options) => tslib_1.__awaiter(void 0, void 0, void 0, function* () {
    const action = yield commands_1.commands.runBuilder();
    action(folder, options, build_kit_1.ENV.DEV, build_kit_1.COMMAND.DEV);
}));
cli
    .command('init <app>', 'Create a new project')
    // if options are modified, param filtering list needs to be updated in the run seed command
    .option('-s, --seed [my-seed]', 'seed')
    .option('--ref [ref]', 'Git ref (branch, tag or commit) to use')
    .option('-x,--skip-optional-prompts', 'Skip prompts with default values')
    .option('--insecure', 'Skip SSL certificate verification')
    .option('--subdir <subdir>', 'subdirectory within seed repo')
    .option('--remote', 'Remote seeds only')
    .option('--no-shell', 'Do not launch a shell in the generated app')
    .option('--no-npm', 'Skip seed resolution from NPM registry')
    .option('--no-scope', 'Do not apply default NPM scope for this seed module')
    .option('-l, --log-level [level]', 'info (default) or verbose')
    .allowUnknownOptions()
    .action((app, options) => tslib_1.__awaiter(void 0, void 0, void 0, function* () {
    const action = yield commands_1.commands.runSeedCommand();
    action(app, options, build_kit_1.COMMAND.INIT);
})).example(`
  ${(0, build_kit_1.bold)('genx init myapp')}
    Create myapp in current folder using default seed (https://github.com/genesiscommunitysuccess/blank-app-seed) following interactive prompts

  ${(0, build_kit_1.bold)('genx init myapp --groupId com.companyName --apiHost ws://localhost:9064 --no-enableSSO')}
    Create myapp using default seed pre-filling prompt answers

  ${(0, build_kit_1.bold)('genx init myapp -x')}
  ${(0, build_kit_1.bold)('genx init myapp --skip-optional-prompts')}
    Create myapp pre-filling all prompts which have default values

  ${(0, build_kit_1.bold)('genx init myapp -s devtraining-seed')}
  ${(0, build_kit_1.bold)('genx init myapp --seed devtraining-seed')}
    Create myapp using a genesiscommunitysuccess seed
    If devtraining-seed exists in current folder, it will be used. Otherwise, it will be downloaded from NPM or GitHub.
    To only use remote seeds pass --remote.

  ${(0, build_kit_1.bold)('genx init myapp -s blank-app-seed --ref develop')}
    Create myapp using a genesiscommunitysuccess seed and  NPM dist tag or Git reference (branch/tag/commit SHA)

  ${(0, build_kit_1.bold)('genx init myapp -s githubuser/repo')}
    Create myapp using a custom seed

  ${(0, build_kit_1.bold)('genx init myapp -s ./path/to/blank-app-seed')}
    Create myapp using local seed (assuming blank-app-seed exists in specified location)

  ${(0, build_kit_1.bold)('genx init myapp -s blank-app-seed --subdir samplepath')}
    Create myapp using seed in subdir folder of blank-app-seed

  ${(0, build_kit_1.bold)('genx init myapp -s blank-app-seed --remote')}
    Create myapp using remote blank-app-seed seed (even if blank-app-seed exists locally)

  ${(0, build_kit_1.bold)('genx init myapp --insecure')}
    Create myapp with SSL certificate validation disabled

  ${(0, build_kit_1.bold)('genx init myapp --no-shell')}
    Create myapp without opening a new shell in the updated app directory

  ${(0, build_kit_1.bold)('genx init myapp --log-level verbose')}
    Create myapp with verbose logging
`);
cli
    .command('add [app]', 'Add functionality to an existing project')
    // if options are modified, param filtering list needs to be updated in the run seed command
    .option('-s, --seed <my-seed>', 'seed')
    .option('--subdir <subdir>', 'subdirectory within seed repo')
    .option('--ref [ref]', 'Git ref (branch, tag or commit) to use')
    .option('-x,--skip-optional-prompts', 'Skip prompts with default values')
    .option('--insecure', 'Skip SSL certificate verification')
    .option('--remote', 'Remote seeds only')
    .option('--no-shell', 'Do not launch a shell in the generated app')
    .option('--no-npm', 'Skip seed resolution from NPM registry')
    .option('--no-scope', 'Do not apply default NPM scope for this seed module')
    .option('-l, --log-level [level]', 'info (default) or verbose')
    .allowUnknownOptions()
    .action((app = '.', options) => tslib_1.__awaiter(void 0, void 0, void 0, function* () {
    const action = yield commands_1.commands.runSeedCommand();
    action(app, options, build_kit_1.COMMAND.ADD);
})).example(`
  ${(0, build_kit_1.bold)('genx add -s devtraining-seed')}
  ${(0, build_kit_1.bold)('genx add -s ../devtraining-seed')}
    Add functionality in genesiscommunitysuccess devtraining-seed seed to the app in current folder

  ${(0, build_kit_1.bold)('genx add myapp -s devtraining-seed')}
  ${(0, build_kit_1.bold)('genx add myapp --seed devtraining-seed')}
    Add functionality in genesiscommunitysuccess devtraining-seed seed to myapp
    If devtraining-seed exists in current folder, it will be used. Otherwise, it will be downloaded from NPM or GitHub.
    To only use remote seeds pass --remote.

  ${(0, build_kit_1.bold)('genx add myapp -s devtraining-seed --subdir folder1')}
    Add functionality in genesiscommunitysuccess devtraining-seed seed folder1 to myapp

  ${(0, build_kit_1.bold)('genx add myapp -s blank-app-seed --ref develop')}
    Add functionality in genesiscommunitysuccess seed and NPM dist tag or Git reference (branch/tag/commit SHA) to myapp

  ${(0, build_kit_1.bold)('genx add myapp -s githubuser/repo')}
    Add functionality in custom seed to myapp

  ${(0, build_kit_1.bold)('genx add myapp -s ./path/to/blank-app-seed')}
    Add functionality in local seed (assuming blank-app-seed exists in specified location) to myapp

  ${(0, build_kit_1.bold)('genx add myapp -s blank-app-seed --remote')}
    Add functionality in remote blank-app-seed seed (even if blank-app-seed exists locally) to myapp

  ${(0, build_kit_1.bold)('genx add myapp -s blank-app-seed --insecure')}
    Update myapp with SSL certificate validation disabled

  ${(0, build_kit_1.bold)('genx add myapp -s blank-app-seed --no-shell')}
    Update myapp without opening a new shell in the generated app directory

  ${(0, build_kit_1.bold)('genx add myapp -s blank-app-seed --log-level verbose')}
    Update myapp with verbose logging
`);
cli
    .command('run <task> [module]', 'Run monorepo task')
    .allowUnknownOptions()
    .action((task, module, options) => tslib_1.__awaiter(void 0, void 0, void 0, function* () {
    const action = yield commands_1.commands.run();
    action(task, module, options);
}));
cli
    .command('serve [folder]', 'Start static file server (defaults to dist folder)')
    .option('-p, --port <port>', 'Port number')
    .action((folder, options) => tslib_1.__awaiter(void 0, void 0, void 0, function* () {
    const action = yield commands_1.commands.serve();
    action(folder, options);
}));
cli
    .command('test [folder]', 'Run tests')
    .option('-m, --match <pattern>', `Test file pattern, ie. fileA.test.ts, '(fileA|fileB).test.ts', file*.test.ts. Defaults to test.ts in node, and ./**/*.test.ts in browser.`)
    .option('--raw-match', `Match raw pattern`)
    .option('-c, --coverage', 'Produce coverage report')
    .option('-w, --watch', 'Watch files for changes')
    .option('-d, --debug', 'Debug test execution')
    .option('--e2e', 'Run e2e tests. Defaults to unit tests.')
    .option('-i, --interactive', 'Run e2e tests in interactive UI mode')
    .option('-b, --browser', 'Execute unit test in a browser. Defaults to Node.js.')
    .option('-e, --env <ENV_VAR1=VAL1,ENV_VAR2=VAL2,ENV3>', 'Set environment variables')
    .action((folder, options) => tslib_1.__awaiter(void 0, void 0, void 0, function* () {
    const action = yield commands_1.commands.runBuilder();
    action(folder, options, build_kit_1.ENV.TEST, build_kit_1.COMMAND.TEST);
}));
cli
    .command('lint [folder]', 'Lint TypesSript and style files')
    .option('-l, --linter <linter>', 'eslint, stylelint or all (default)')
    .option('-f, --fix', 'Fix issues')
    .option('-p, --profile', 'Output profiling information')
    .option('-b, --builder <builder>', 'Override default builder')
    .action((folder, options) => tslib_1.__awaiter(void 0, void 0, void 0, function* () {
    const action = yield commands_1.commands.runBuilder();
    action(folder, options, build_kit_1.ENV.DEV, build_kit_1.COMMAND.LINT);
}));
cli
    .command('upgrade [folder]', 'Upgrade Foundation UI dependencies')
    .option('-r, --respect-version-ranges', 'Update within package.json version ranges (defaults to latest otherwise)')
    .option('-x, --exclude <list>', 'Comma-separated list of packages to exclude')
    .action((folder, options) => tslib_1.__awaiter(void 0, void 0, void 0, function* () {
    const action = yield commands_1.commands.upgrade();
    action(folder, options);
}));
// display help message when `-h` or `--help` appears
cli.help();
// display version number when `-v` or `--version` appears
cli.version(packageJSON.version);
(() => tslib_1.__awaiter(void 0, void 0, void 0, function* () {
    try {
        cli.parse(process.argv, { run: false });
        yield cli.runMatchedCommand();
    }
    catch (error) {
        consola_1.consola.error(error.message);
        consola_1.consola.error(error.stack);
        process.exit(1);
    }
}))();
